@@ -59,14 +59,6 @@
 #include "dispatch.h"
 #include "indirect_dispatch.h"
 
-#ifndef GLX_TEXTURE_TARGET_EXT
-#define GLX_TEXTURE_TARGET_EXT              0x6001
-#define GLX_TEXTURE_2D_EXT                  0x6002
-#define GLX_TEXTURE_RECTANGLE_EXT           0x6003
-#define GLX_NO_TEXTURE_EXT                  0x6004
-#define GLX_Y_INVERTED_EXT                  0x6006
-#endif
-
 /************************************************************************/
 
 void
@@ -1926,10 +1918,10 @@ static int __glXBindSwapBarrierSGIX(__GLXclientState *cl, GLbyte *pc)
     XID drawable = req->drawable;
     int barrier = req->barrier;
     DrawablePtr pDraw = (DrawablePtr) LookupDrawable(drawable, client);
-    int screen = pDraw->pScreen->myNum;
-
+    int screen;
 
     if (pDraw && (pDraw->type == DRAWABLE_WINDOW)) {
+	screen = pDraw->pScreen->myNum;
         if (__glXSwapBarrierFuncs &&
             __glXSwapBarrierFuncs[screen].bindSwapBarrierFunc) {
             int ret = __glXSwapBarrierFuncs[screen].bindSwapBarrierFunc(screen, drawable, barrier);
