@@ -1,5 +1,25 @@
 /*
- * $Id: compinit.c,v 1.8 2005/07/03 07:01:17 daniels Exp $
+ * $Id: compinit.c,v 1.9 2005/07/03 07:37:34 daniels Exp $
+ *
+ * Copyright © 2006 Sun Microsystems
+ *
+ * Permission to use, copy, modify, distribute, and sell this software and its
+ * documentation for any purpose is hereby granted without fee, provided that
+ * the above copyright notice appear in all copies and that both that
+ * copyright notice and this permission notice appear in supporting
+ * documentation, and that the name of Sun Microsystems not be used in
+ * advertising or publicity pertaining to distribution of the software without
+ * specific, written prior permission.  Sun Microsystems makes no
+ * representations about the suitability of this software for any purpose.  It
+ * is provided "as is" without express or implied warranty.
+ *
+ * SUN MICROSYSTEMS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
+ * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO
+ * EVENT SHALL SUN MICROSYSTEMS BE LIABLE FOR ANY SPECIAL, INDIRECT OR
+ * CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
+ * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
+ * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+ * PERFORMANCE OF THIS SOFTWARE.
  *
  * Copyright © 2003 Keith Packard
  *
@@ -33,6 +53,7 @@ int	CompWindowPrivateIndex;
 int	CompSubwindowsPrivateIndex;
 int	CompGeneration;
 
+
 static Bool
 compCloseScreen (int index, ScreenPtr pScreen)
 {
@@ -55,9 +76,19 @@ compCloseScreen (int index, ScreenPtr pScreen)
     pScreen->CreateWindow = cs->CreateWindow;
     pScreen->CopyWindow = cs->CopyWindow;
     pScreen->PositionWindow = cs->PositionWindow;
+
+    deleteCompOverlayClientsForScreen(pScreen);
+
+    /* 
+    ** Note: no need to call DeleteWindow; the server has
+    ** already destroyed it.
+    */
+    cs->pOverlayWin = NULL;
+
     xfree (cs);
     pScreen->devPrivates[CompScreenPrivateIndex].ptr = 0;
     ret = (*pScreen->CloseScreen) (index, pScreen);
+
     return ret;
 }
 
@@ -333,6 +364,8 @@ compScreenInit (ScreenPtr pScreen)
 	return FALSE;
 
     cs->damaged = FALSE;
+    cs->pOverlayWin = NULL;
+    cs->pOverlayClients = NULL;
 
     if (!compAddAlternateVisuals (pScreen, cs))
     {
@@ -386,5 +419,8 @@ compScreenInit (ScreenPtr pScreen)
     pScreen->CloseScreen = compCloseScreen;
 
     pScreen->devPrivates[CompScreenPrivateIndex].ptr = (pointer) cs;
+
+    RegisterRealChildHeadProc(CompositeRealChildHead);
+
     return TRUE;
 }
