@@ -557,7 +557,7 @@ exaDriverInit (ScreenPtr		pScreen,
 
     pScreen->devPrivates[exaScreenPrivateIndex].ptr = (pointer) pExaScr;
 
-    pExaScr->migration = ExaMigrationGreedy;
+    pExaScr->migration = ExaMigrationSmart;
 
     exaDDXDriverInit(pScreen);
 
