@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875.  */
+/* A Bison parser, made by GNU Bison 2.1.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -42,6 +42,7 @@
      T_LINE_COMMENT = 268
    };
 #endif
+/* Tokens.  */
 #define T_VIRTUAL 258
 #define T_DISPLAY 259
 #define T_WALL 260
@@ -58,7 +59,7 @@
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 56 "parser.y"
+#line 56 "../../../../hw/dmx/config/parser.y"
 typedef union YYSTYPE {
     DMXConfigTokenPtr      token;
     DMXConfigStringPtr     string;
@@ -75,8 +76,8 @@ typedef union YYSTYPE {
     DMXConfigVirtualPtr    virtual;
     DMXConfigEntryPtr      entry;
 } YYSTYPE;
-/* Line 1240 of yacc.c.  */
-#line 79 "y.tab.h"
+/* Line 1447 of yacc.c.  */
+#line 81 "parser.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
