@@ -146,9 +146,6 @@ static GCOps vgaGCOps = {
 	xf4bppImageGlyphBlt,	/*  GJA -- void (* ImageGlyphBlt)() */
 	miPolyGlyphBlt,		/*  GJA -- void (* PolyGlyphBlt)() */
 	miPushPixels,		/*  void (* PushPixels)() */
-#ifdef NEED_LINEHELPER
-	miMiter,		/*  void (* LineHelper)() */
-#endif
 	{NULL}			/* devPrivate */
 };
 
@@ -244,10 +241,6 @@ while ((idx = LOWBIT(changes))) {
 	    break ;
 
 	case GCJoinStyle:
-#ifdef NEED_LINEHELPER
-	    pGC->ops->LineHelper = ( pGC->joinStyle == JoinMiter )
-			    ? miMiter : miNotMiter ;
-#endif
 	    changes &= ~ idx ; /* i.e. changes &= ~ GCJoinStyle */
 	    break ;
 
