@@ -23,10 +23,6 @@ SOFTWARE.
 ******************************************************************/
 /* $Xorg: dixstruct.h,v 1.3 2000/08/17 19:53:29 cpqbld Exp $ */
 
-#ifdef HAVE_DIX_CONFIG_H
-#include <dix-config.h>
-#endif
-
 #ifndef DIXSTRUCT_H
 #define DIXSTRUCT_H
 
@@ -132,9 +128,6 @@ typedef struct _Client {
 #ifdef DEBUG
     unsigned char requestLog[MAX_REQUEST_LOG];
     int         requestLogIndex;
-#endif
-#ifdef LBX
-    int		(*readRequest)(ClientPtr /*client*/);
 #endif
     unsigned long replyBytesRemaining;
 #ifdef XCSECURITY
