@@ -1,4 +1,4 @@
-/* $XdotOrg: xserver/xorg/include/globals.h,v 1.9 2005/08/24 11:18:31 daniels Exp $ */
+/* $XdotOrg: xserver/xorg/include/globals.h,v 1.12 2006/06/01 22:06:40 daniels Exp $ */
 /* $XFree86: xc/programs/Xserver/include/globals.h,v 1.3 1999/09/25 14:38:21 dawes Exp $ */
 
 #ifndef _XSERV_GLOBAL_H_
@@ -13,6 +13,10 @@ extern CARD32 defaultScreenSaverInterval;
 extern CARD32 ScreenSaverTime;
 extern CARD32 ScreenSaverInterval;
 
+#ifdef SCREENSAVER
+extern Bool screenSaverSuspended;
+#endif
+
 extern char *defaultFontPath;
 extern char *rgbPath;
 extern int monitorResolution;
@@ -64,10 +68,6 @@ extern Bool noDamageExtension;
 extern Bool noDbeExtension;
 #endif
 
-#ifdef DPSEXT
-extern Bool noDPSExtension;
-#endif
-
 #ifdef DPMSExtension
 extern Bool noDPMSExtension;
 #endif
@@ -84,10 +84,6 @@ extern Bool noFontCacheExtension;
 extern Bool noGlxExtension;
 #endif
 
-#ifdef LBX
-extern Bool noLbxExtension;
-#endif
-
 #ifdef SCREENSAVER
 extern Bool noScreenSaverExtension;
 #endif
