@@ -1,5 +1,5 @@
 /*
- * $Id$
+ * $Id: damage.c,v 1.20 2006/02/10 22:00:30 anholt Exp $
  *
  * Copyright © 2003 Keith Packard
  *
@@ -1637,9 +1637,6 @@ GCOps damageGCOps = {
     damagePolyText16, damageImageText8,
     damageImageText16, damageImageGlyphBlt,
     damagePolyGlyphBlt, damagePushPixels,
-#ifdef NEED_LINEHELPER
-    NULL,
-#endif
     {NULL}		/* devPrivate */
 };
 
